# Global variables
_HEADER = {"Content-Type": "application/json"}
_PAYLOAD = {}